==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/S6841b111b8f592b462ad9f34cc032c0a.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#ifndef S561ef0f415498420b6a84b0c4b9421cd
 
#define S561ef0f415498420b6a84b0c4b9421cd
 
#include "S21d6f40cfb511982e4424e0e250a9557.h"

#include "Se212bcaaa6416f3692b6fa96bb03af95.h"
 class S9c023f942cf5210c8f3affabe7ed7196 { public: unsigned long S238ea9441fe9ad7f8478d3178e384627; 
unsigned long S32af80f1a091b3ca8e5bdc1a13c45cb9; unsigned long S8f1228fcba0504e47b468b829861d81b; unsigned 
long S56e552fb20cf2a9e5153fe195bc5ba6d; unsigned long S95a65992257dc054ba206a1c0a26e04a; unsigned long 
S8c6b630c69e285c96ab2c1347a83d696; unsigned long Sf570f726ab560947abf01b08bb87afee; double Sc7cd82b45d803418c810cfab7b9af6d4; 
double S0d39cf689a0ca5e858c10097d7aaac3e; double S6ffdd8c7674fd0bc6eb4d8f67a4d6c41; S8fe59ef6e1e9f87740040549ec149682 
S76dc85487a40b9de6898b8328177bcd6; S71c7ae294b7abd866b3fb295b3b9e4a4 **S161bca2e917335e125291a00fd76a80f; 
unsigned long S16d027da9851b664ff9336caf28769e8; unsigned long S232615c2dfe1e579ad6cf375812c7005; unsigned 
long S5c654d38ae1ff442e0f586df4d6ac69b; bool *Sa9aa4fa1af6d5992b330a7e58079b05f; bool *S649c6d8e19c3e23a46b2a549e473c00b; 
S9c023f942cf5210c8f3affabe7ed7196(Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179); 
~S9c023f942cf5210c8f3affabe7ed7196(); void S526d688f37a86d3c3f27d0c5016eb71d(void); };  
#endif

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S6841b111b8f592b462ad9f34cc032c0a.h <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#ifndef S561ef0f415498420b6a84b0c4b9421cd
 
#define S561ef0f415498420b6a84b0c4b9421cd
 
#include "S21d6f40cfb511982e4424e0e250a9557.h"

#include "Se212bcaaa6416f3692b6fa96bb03af95.h"
 class S9c023f942cf5210c8f3affabe7ed7196 { public: unsigned long S238ea9441fe9ad7f8478d3178e384627; 
unsigned long S32af80f1a091b3ca8e5bdc1a13c45cb9; unsigned long S8f1228fcba0504e47b468b829861d81b; unsigned 
long S56e552fb20cf2a9e5153fe195bc5ba6d; unsigned long S95a65992257dc054ba206a1c0a26e04a; unsigned long 
S8c6b630c69e285c96ab2c1347a83d696; unsigned long Sf570f726ab560947abf01b08bb87afee; double Sc7cd82b45d803418c810cfab7b9af6d4; 
double S0d39cf689a0ca5e858c10097d7aaac3e; double S6ffdd8c7674fd0bc6eb4d8f67a4d6c41; double Scc92c8e24a7e12aaeb964bd9739bb332; 
 S8fe59ef6e1e9f87740040549ec149682 S76dc85487a40b9de6898b8328177bcd6; S71c7ae294b7abd866b3fb295b3b9e4a4 
**S161bca2e917335e125291a00fd76a80f; unsigned long S16d027da9851b664ff9336caf28769e8; unsigned long 
S232615c2dfe1e579ad6cf375812c7005; unsigned long S5c654d38ae1ff442e0f586df4d6ac69b; bool *Sa9aa4fa1af6d5992b330a7e58079b05f; 
bool *S649c6d8e19c3e23a46b2a549e473c00b; S9c023f942cf5210c8f3affabe7ed7196(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179); ~S9c023f942cf5210c8f3affabe7ed7196(); void S526d688f37a86d3c3f27d0c5016eb71d(void); 
};  
#endif
